@@ -8,15 +8,7 @@
 #
 ################################################################################
 #
-# $Project: /Convert-Binary-C $
-# $Author: mhx $
-# $Date: 2007/06/11 20:59:50 +0200 $
-# $Revision: 32 $
-# $Source: /lib/Convert/Binary/C/Cached.pm $
-#
-################################################################################
-#
-# Copyright (c) 2002-2007 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2020 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -31,8 +23,7 @@ use vars qw( @ISA $VERSION );
 
 @ISA = qw(Convert::Binary::C);
 
-$VERSION = do { my @r = '$Snapshot: /Convert-Binary-C/0.69_01 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
-$VERSION = eval $VERSION;
+$VERSION = '0.79_01';
 
 sub new
 {
@@ -236,7 +227,7 @@ sub __parse
 sub __can_use_cache
 {
   my $self = shift;
-  my $fh = new IO::File;
+  my $fh = IO::File->new;
 
   unless (-e $self->{cache} and -s _) {
     $ENV{CBCC_DEBUG} and print STDERR "CBCC: cache file '$self->{cache}' doesn't exist or is empty\n";
@@ -249,6 +240,7 @@ sub __can_use_cache
     return 0;
   }
 
+  my @warnings;
   my @config = do {
     my $config;
     unless (defined($config = <$fh>)) {
@@ -262,11 +254,12 @@ sub __can_use_cache
     local $/ = $/.'#endif';
     chomp($config = <$fh>);
     $config =~ s/^\*//gms;
+    local $SIG{__WARN__} = sub { push @warnings, $_[0] };
     eval $config;
   };
 
   # corrupt config
-  if (@config % 2) {
+  if ($@ or @warnings or @config % 2) {
     $ENV{CBCC_DEBUG} and print STDERR "CBCC: broken configuration\n";
     return 0;
   }
@@ -311,7 +304,7 @@ sub __can_use_cache
 sub __save_cache
 {
   my $self = shift;
-  my $fh = new IO::File;
+  my $fh = IO::File->new;
 
   $fh->open(">$self->{cache}") or croak "Cannot open '$self->{cache}': $!";
 
@@ -373,7 +366,8 @@ Convert::Binary::C::Cached - Caching for Convert::Binary::C
   $c = Convert::Binary::C::Cached->new(
          Cache   => '/tmp/cache.c',
          Include => [
-           '/usr/lib/gcc-lib/i686-pc-linux-gnu/3.3.6/include',
+           '/usr/lib/gcc/x86_64-pc-linux-gnu/10.2.0/include',
+           '/usr/lib/gcc/x86_64-pc-linux-gnu/10.2.0/include-fixed',
            '/usr/include',
          ],
        );
@@ -444,7 +438,7 @@ algorithm cannot detect that an update is required.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2007 Marcus Holland-Moritz. All rights reserved.
+Copyright (c) 2002-2020 Marcus Holland-Moritz. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
@@ -453,4 +447,3 @@ it under the same terms as Perl itself.
 See L<Convert::Binary::C>.
 
 =cut
-
